@@ -222,10 +222,10 @@ void MainWindow::readSettings()
     ui->horizontalSlider_3->setValue(snap);
     }
 
-    if ( opacity > 0 ) {
+ //   if ( opacity > 0 ) {
     ui->Opacity->setText(opacitystring);
     ui->horizontalSlider_4->setValue(opacity);
-    }
+ //   }
 
 }
 
@@ -233,15 +233,8 @@ void MainWindow::SetOpacity(QString imagefile, int opacity)
 {
 
     QPixmap temp;
-    imagefile = QFileInfo(imagefile).symLinkTarget();
-    QString imagebackup = "/opt/theme-customizer/backups/" + imagefile;
-    // First of all, let's check if the backup exists
-    if ( !QFileInfo(imagefile).exists() && !QFileInfo(imagebackup).exists() ) {
-    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'No image found...!' uint32:0 string:'OK'");
-    return;
-    }
-    // QString imagebackup = "/opt/theme-customizer/backups/" + imagefile;
-    // Set image opacity using the original image we have created
+    QString realimagefile = QFileInfo("/etc/hildon/theme/images/" + imagefile).canonicalFilePath();
+    QString imagebackup = "/opt/theme-customizer/backups/" + realimagefile;
     temp = QPixmap(imagebackup);
     QPixmap transparent(temp.size());
     transparent.fill(Qt::transparent);
@@ -252,7 +245,7 @@ void MainWindow::SetOpacity(QString imagefile, int opacity)
     p.fillRect(transparent.rect(), QColor(0, 0, 0, opacity));  // opacity value can be 0-255
     p.end();
     // Save the new image
-    transparent.save(imagefile);
+    transparent.save(realimagefile);
     // system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'Image saved!' uint32:0 string:'OK'");
 
 }
@@ -285,7 +278,7 @@ void MainWindow::on_pushButton_clicked()
         arguments << ui->FontSize->currentText() << ui->Fonter->currentText() << ui->Iconset->currentText() << Icons << ui->lineEdit->text() << ui->Snap->text() << checkboxstate << fonts << f1 << f2 << f3 << f4 << ui->lineEdit_2->text() << f5 << f6 << f7 << f8 << ui->Opacity->text();
         QProcess *process = new QProcess(this);
         connect(process, SIGNAL(finished(int)), this, SLOT(processFinished(int)));
-        process->start("/sbin/customizer", arguments);
+        process->start("/sbin/launchcustomizer", arguments);
         progress.show();
 
 }
@@ -294,20 +287,20 @@ void MainWindow::processFinished(int)
 {
     int opasity = ui->Opacity->text().toInt();
     system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Setting up widget opacities...'");
-    SetOpacity("/etc/hildon/theme/images/ApplicationShortcutApplet.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/CalendarAppletBackground.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/ContactsAppletFrame.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/MapAppletButton.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/MapAppletHead.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/MediaPlayerAppletHead.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/MediaPlayerAppletNext.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/MediaPlayerAppletPrevious.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/MediaPlayerAppletStopPlay.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/OviCenter.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/OviLeft.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/OviRight.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/RSSAppletHead.png", opasity);
-    SetOpacity("/etc/hildon/theme/images/WebShortcutAppletBackground.png", opasity);
+    SetOpacity("ApplicationShortcutApplet.png", opasity);
+    SetOpacity("CalendarAppletBackground.png", opasity);
+    SetOpacity("ContactsAppletFrame.png", opasity);
+    SetOpacity("MapAppletButton.png", opasity);
+    SetOpacity("MapAppletHead.png", opasity);
+    SetOpacity("MediaPlayerAppletHead.png", opasity);
+    SetOpacity("MediaPlayerAppletNext.png", opasity);
+    SetOpacity("MediaPlayerAppletPrevious.png", opasity);
+    SetOpacity("MediaPlayerAppletStopPlay.png", opasity);
+    SetOpacity("OviCenter.png", opasity);
+    SetOpacity("OviLeft.png", opasity);
+    SetOpacity("OviRight.png", opasity);
+    SetOpacity("RSSAppletHead.png", opasity);
+    SetOpacity("WebShortcutAppletBackground.png", opasity);
 
     if ( ui->checkBoxActivate->checkState() == Qt::Unchecked ) {
 
@@ -319,15 +312,16 @@ void MainWindow::processFinished(int)
         system("sleep 2 && killall hildon-status-menu");
         system("sleep 2 && killall systemui");
         system("sleep 2 && killall hildon-desktop");
-        system("sleep 2 && killall theme-customizer");
+        system("killall theme-customizer");
 
-    }
+    } else {
 
     system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Rebooting in 5 seconds, fasten your seatbelts!'");
-    system("sleep 2");
-    system("reboot");
-//    progress.cancel();
-//    oldfonts();
+    system("/sbin/launchcustomizer rebootnow");
+    progress.cancel();
+    oldfonts();
+
+}
 
 }
 
