@@ -13,6 +13,8 @@
 #include <QPixmap>
 #include <QImage>
 #include "backgrounds.h"
+#include <QFileInfo>
+#include <QPainter>
 
 namespace Ui {
     class MainWindow;
@@ -40,6 +42,7 @@ private:
     QHash<QString, QString> gtkrc;
     void readSettings();
     void writeSettings();
+    void SetOpacity(QString imagefile, int opacity);
     QString f1;
     QString f2;
     QString f3;
