@@ -120,8 +120,8 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
-        <source>Widget opacity %</source>
-        <translation>Widgettien näkyvyys %</translation>
+        <source>Widget opacity</source>
+        <translation>Widgettien näkyvyys</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="560"/>
