@@ -122,9 +122,8 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
-        <source>Widget opacity %</source>
-        <translation type="unfinished">
-</translation>
+        <source>Widget opacity</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="560"/>
